summaryrefslogtreecommitdiffstats
path: root/templates/annotated/systray1.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/systray1.py')
-rw-r--r--templates/annotated/systray1.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/templates/annotated/systray1.py b/templates/annotated/systray1.py
index e911f38..1537fbc 100644
--- a/templates/annotated/systray1.py
+++ b/templates/annotated/systray1.py
@@ -36,7 +36,7 @@ copyright holder.
import sys
from qt import TQLabel, TQWidget, SIGNAL
-from tdecore import KApplication, KIcon, KIconLoader
+from tdecore import TDEApplication, KIcon, KIconLoader
from tdeui import KMainWindow, KSystemTray
# This template uses KMainWindow as the main window widget
@@ -70,15 +70,15 @@ class MainWin (KMainWindow):
# system tray icon's menu
def slotQuitSelected (self):
self.exitFlag = True
- KApplication.kApplication ().quit ()
+ TDEApplication.kApplication ().quit ()
#-------------------- main ------------------------------------------------
# The usual stuff - you can also use the KAboutData/KCmdLineArgs version
# for program startup used in other templates - the KApplication constructor
# used here may be obsoleted eventually
appName = "template"
-app = KApplication (sys.argv, appName)
+app = TDEApplication (sys.argv, appName)
mainWindow = MainWin (None, "main window")
mainWindow.show()
@@ -70,15 +70,15 @@ class MainWin (KMainWindow):
#-------------------- main ------------------------------------------------
# The usual stuff - you can also use the KAboutData/KCmdLineArgs version
-# for program startup used in other templates - the KApplication constructor
+# for program startup used in other templates - the TDEApplication constructor
# used here may be obsoleted eventually
appName = "template"